@@ -9,17 +9,14 @@ __title__ = 'githubapps'
 __author__ = 'RTa-technology'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2022 by the authors and contributors (see AUTHORS)'
-__version__ = '0.1.0'
+__version__ = '1.0.0'
 
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
-from .adapter import Auth, Authentication
+from .adapter import Authentication, RequestsAuth, AiohttpAuth
 
 from .errors import (BadRequest, Forbidden, HTTPException, InternalServerError,
                      NotFound, PayloadTooLarge, QuotaExceeded,
                      ServiceUnavailable, TooManyRequests, URITooLong)
 
-__all__ = [
-  'Adapter',
-  'Auth'
-]
\ No newline at end of file
+__all__ = ['Authentication', 'RequestsAuth', 'AiohttpAuth']
\ No newline at end of file
